<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:adf="urn:avicomsys-ru:adf-preview">
  <xsl:variable name="lang" select="adf:GetLanguage()" />
	<xsl:template match="/">
		<HTML>
			<HEAD>
				<TITLE>
					<xsl:value-of select="pjm5ServiceRequestGet/ServiceRequest/FileAs" />
				</TITLE>
				<xsl:value-of select="adf:GetCss()" disable-output-escaping="yes" />
			</HEAD>
			<BODY >
				<xsl:value-of select="adf:GetHeader(pjm5ServiceRequestGet/ServiceRequest)"  disable-output-escaping="yes"/>
				<xsl:apply-templates select="//ServiceRequest"/>
				<br />
				<xsl:choose>
					<xsl:when test="//Line/ID">

						<table border="1" cellspacing="0" cellpadding="4">
							<tr>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Наименование
                    </xsl:when>
                    <xsl:otherwise>
                      File As
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Описание
                    </xsl:when>
                    <xsl:otherwise>
                      Description
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Ед.измерения
                    </xsl:when>
                    <xsl:otherwise>
                      Unit Of Measure
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      По заявке
                    </xsl:when>
                    <xsl:otherwise>
                      Requested
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Выполнено
                    </xsl:when>
                    <xsl:otherwise>
                      Executed
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Цена
                    </xsl:when>
                    <xsl:otherwise>
                      Price
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Сумма
                    </xsl:when>
                    <xsl:otherwise>
                      Value
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
								<th>
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Валюта
                    </xsl:when>
                    <xsl:otherwise>
                      Currency
                    </xsl:otherwise>
                  </xsl:choose>
                </th>
							</tr>
							<xsl:for-each select="//Line">
								<xsl:apply-templates select="."/>
							</xsl:for-each>
						</table>

					</xsl:when>
					<xsl:otherwise>	</xsl:otherwise>
				</xsl:choose>
				<xsl:value-of select="adf:GetFooter(pjm5ServiceRequestGet/ServiceRequest)"  disable-output-escaping="yes"/>

			</BODY>
		</HTML>
	</xsl:template>

	<xsl:template match="Line">
		<tr>
			<td>
				<xsl:value-of select="FileAs"/>				
			</td>
			<td>
				<xsl:value-of select="Description"/>
			</td>
			<td>
				<xsl:value-of select="Unit"/>
			</td>
			<td align="right">
				<xsl:variable name="x" select="RequestAmount"/>
				<xsl:value-of select="format-number($x,'0.##')"/>
			</td>
			<td align="right">
				<xsl:variable name="y" select="FactAmount"/>
				<xsl:value-of select="format-number($y,'0.##')"/>
			</td>
			<td align="right">
        <xsl:variable name="z" select="Price"/>
        <xsl:choose>
          <xsl:when test="$z = -1">
            <xsl:value-of select="string('*****')"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="format-number($z,'0.##')"/>
          </xsl:otherwise>
        </xsl:choose>     
			</td>
			<td align="right">
				<xsl:variable name="u" select="Sum"/>
        <xsl:choose>
          <xsl:when test="$u = -1">
            <xsl:value-of select="string('*****')"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="format-number($u,'0.##')"/>
          </xsl:otherwise>
        </xsl:choose>

			</td>
			<td>
				<xsl:apply-templates select="//ServiceRequest/CurrencyCode"/>
			</td>
		</tr>
	</xsl:template>

	<xsl:template match="CurrencyCode">
		<xsl:value-of select="."/>
	</xsl:template>
	
	<xsl:template match="ServiceRequest">
		<table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="SupplierCompanyID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Поставщик:
                  </xsl:when>
                  <xsl:otherwise>
                    Supplier:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(SupplierCompanyID, 'Company', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="CustomerCompanyID">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Покупатель:
                  </xsl:when>
                  <xsl:otherwise>
                    Customer:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(CustomerCompanyID, 'Company', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="EmployeeID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Исполнитель:
                  </xsl:when>
                  <xsl:otherwise>
                    Assignment:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(EmployeeID, 'Employee', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	</xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="DueDate">
							<br/>
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Исполнить до:
                  </xsl:when>
                  <xsl:otherwise>
                    Due Date:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:FormatXmlDate(DueDate,'d')"/>
							<xsl:text> </xsl:text>
							<xsl:value-of select="adf:FormatXmlDate(DueDate,'t')"/>
						</xsl:when>
						<xsl:otherwise> </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="ContractNumber">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Договор:
                  </xsl:when>
                  <xsl:otherwise>
                    Project Code:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="ContractNumber"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:choose>
						<xsl:when test="PriorityID">
							<br />
							<strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Приоритет:
                  </xsl:when>
                  <xsl:otherwise>
                    Priority:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
							<xsl:value-of select="adf:GetListMember(PriorityID, 'Priority', 'Name')"/>
						</xsl:when>
						<xsl:otherwise>	 </xsl:otherwise>
					</xsl:choose>
				</td>
			</tr>
      <xsl:choose>
        <xsl:when test="adf:GetParameter('Pjm5','AdvancedTimeExpensesForm')='True'">
          <tr>
            <td>
              <xsl:choose>
                <xsl:when test="ManHour">
                  <br />
                  <strong>
                    <xsl:choose>
                      <xsl:when test="$lang = 'ru'">
                        Трудозатраты:
                      </xsl:when>
                      <xsl:otherwise>
                        ManHour:
                      </xsl:otherwise>
                    </xsl:choose>
                  </strong>
                  <br />
                      <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Планируемая:
                  </xsl:when>
                  <xsl:otherwise>
                    Planned
                  </xsl:otherwise>
                </xsl:choose>
              <xsl:variable name="x" select="ManHour" />
                  <xsl:choose>
                    <xsl:when test="($x div 60) >= 1">
                      <xsl:value-of select="format-number(($x - ($x mod 60)) div 60,'0')"/>
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          час.
                        </xsl:when>
                        <xsl:otherwise>
                          hour.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>
                    <xsl:when test="($x div 60) = 0">
                      <xsl:value-of select="format-number(0,'0')"/>
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          мин.
                        </xsl:when>
                        <xsl:otherwise>
                          min.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>  </xsl:otherwise>
                  </xsl:choose>
                  <xsl:choose>
                    <xsl:when test="($x mod 60) != 0">
                      <xsl:value-of select="format-number($x mod 60,'0')"/>
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          мин.
                        </xsl:when>
                        <xsl:otherwise>
                          min.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>

                    <xsl:otherwise>  </xsl:otherwise>
                  </xsl:choose>
                  <br />
                 <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Фактическая:
                    </xsl:when>
                    <xsl:otherwise>
                      Real:
                    </xsl:otherwise>
                  </xsl:choose><xsl:variable name="y" select="ActualManHour"/>
                  <xsl:choose>
                    <xsl:when test="($y div 60) >= 1">
                      <xsl:value-of select="format-number(($y - ($y mod 60)) div 60,'0')"/>
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          час.
                        </xsl:when>
                        <xsl:otherwise>
                          hour.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>
                    <xsl:when test="($y div 60) = 0">
                      <xsl:value-of select="format-number(0,'0')"/>
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          мин.
                        </xsl:when>
                        <xsl:otherwise>
                          min.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>  </xsl:otherwise>
                  </xsl:choose>
                  <xsl:choose>
                    <xsl:when test="($y mod 60) != 0">
                      <xsl:value-of select="format-number($y mod 60,'0')"/>
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          мин.
                        </xsl:when>
                        <xsl:otherwise>
                          min.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>  </xsl:otherwise>
                  </xsl:choose>
                  <br />
                </xsl:when>
                <xsl:otherwise>	 </xsl:otherwise>
              </xsl:choose>
            </td>
          </tr>
          <xsl:choose>
            <xsl:when test="FinanceEnable = 'true'">
              <tr>
                <td>
                  <xsl:choose>
                    <xsl:when test="ActualBudget">
                      <br />
                      <strong>
                        <xsl:choose>
                          <xsl:when test="$lang = 'ru'">
                            Бюджет:
                          </xsl:when>
                          <xsl:otherwise>
                            Budget:
                          </xsl:otherwise>
                        </xsl:choose>
                      </strong>
                      <br />
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          Фактический:
                        </xsl:when>
                        <xsl:otherwise>
                          Real:
                        </xsl:otherwise>
                      </xsl:choose><xsl:variable name="bf" select="ActualBudget"/>
                      <xsl:value-of select="format-number($bf,'0.##')"/> <xsl:text> </xsl:text> <xsl:value-of select="CurrencyCode"/> <br />
                    </xsl:when>
                    <xsl:otherwise>	 </xsl:otherwise>
                  </xsl:choose>
                </td>
              </tr>
            </xsl:when>
          </xsl:choose>
        </xsl:when>
      </xsl:choose>
			<tr>
				<td>
					<br />
					<strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                К оплате:
              </xsl:when>
              <xsl:otherwise>
                Billable:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
					<xsl:choose>
						<xsl:when test="Billable='true'">
								<input id="Checkbox1" checked="checked" type="checkbox" disabled="true"  />
							</xsl:when>
						</xsl:choose>
					<xsl:choose>
						<xsl:when test="Billable='false'">
							<input id="Checkbox1" type="checkbox" disabled="true"  />
						</xsl:when>
							</xsl:choose>
				</td>
			</tr>
			<tr>
				<td>
					<br />
					<strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Цена указана с НДС:
              </xsl:when>
              <xsl:otherwise>
                VAT Is Included:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
					<xsl:choose>
					<xsl:when test="VATIsIncluded='true'">
						<input id="Checkbox2" checked="checked" type="checkbox"  disabled="true"  />
					</xsl:when>
				</xsl:choose>
					<xsl:choose>
						<xsl:when test="VATIsIncluded='false'">
							<input id="Checkbox2" type="checkbox" disabled="true" />
						</xsl:when>
					</xsl:choose>
				</td>
			</tr>
      <tr>
        <td>
          <xsl:choose>
            <xsl:when test="Description">
              <br />
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Описание:
                  </xsl:when>
                  <xsl:otherwise>
                    Description:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:value-of select="Description"/>
            </xsl:when>
            <xsl:otherwise>	 </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
		</table>
	</xsl:template>
</xsl:stylesheet>