<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:adf="urn:avicomsys-ru:adf-preview">
  <xsl:variable name="lang" select="adf:GetLanguage()" />
  <xsl:template match="/">
    <HTML>
      <HEAD>
        <TITLE>
          <xsl:value-of select="pjm5TaskRequestGet/TaskRequest/FileAs" />
        </TITLE>
        <xsl:value-of select="adf:GetCss()" disable-output-escaping="yes" />
      </HEAD>
      <BODY >
        <xsl:value-of select="adf:GetHeader(pjm5TaskRequestGet/TaskRequest)"  disable-output-escaping="yes"/>
        <xsl:apply-templates select="//TaskRequest"/>
        <xsl:choose>
          <xsl:when test="pjm5TaskRequestGet/TaskRequestAssignment">
            <table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">
              <tr>
                <td>
                  <br />
                  <strong>
                    <xsl:choose>
                      <xsl:when test="$lang = 'ru'">
                        Исполнители:
                      </xsl:when>
                      <xsl:otherwise>
                        Assignments:
                      </xsl:otherwise>
                    </xsl:choose>
                  </strong>
                  <xsl:for-each select="pjm5TaskRequestGet/TaskRequestAssignment">
                    <xsl:apply-templates select="."/>
                  </xsl:for-each>
                </td>
              </tr>
            </table>
          </xsl:when>
        </xsl:choose>
        <xsl:value-of select="adf:GetFooter(pjm5TaskRequestGet/TaskRequest)"  disable-output-escaping="yes"/>
      </BODY>
    </HTML>
  </xsl:template>
  <xsl:template match="TaskRequestAssignment">
    <table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">
      <tr>
        <td>
          <br />
          <xsl:value-of select="adf:GetListMember(EmployeeID, 'Employee', 'Name')"/>
        </td>
      </tr>
    </table>
  </xsl:template>

  <xsl:template match="TaskRequest">
    <table style="font-family:Verdana;font-size:8pt" cellspacing="0" cellpadding="0" border="0">
      <tr>
        <td>
          <br />
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Проект:
              </xsl:when>
              <xsl:otherwise>
                Project:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:choose>
            <xsl:when test="ProjectID">
              <xsl:value-of select="adf:GetListMember(ProjectID, 'Project', 'Name')"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  (Не указан)
                </xsl:when>
                <xsl:otherwise>
                  (none)
                </xsl:otherwise>
              </xsl:choose>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <br />
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Начало:
              </xsl:when>
              <xsl:otherwise>
                Start Date:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:choose>
            <xsl:when test="StartTime">
              <xsl:value-of select="adf:FormatXmlDate(StartTime,'d')"/>
              <xsl:text > </xsl:text>
              <xsl:value-of select="adf:FormatXmlDate(StartTime,'t')"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  (Не указан)
                </xsl:when>
                <xsl:otherwise>
                  (none)
                </xsl:otherwise>
              </xsl:choose>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <br />
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Исполнить до:
              </xsl:when>
              <xsl:otherwise>
                Due Date:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:choose>
            <xsl:when test="DueTime">
              <xsl:value-of select="adf:FormatXmlDate(DueTime,'d')"/>
              <xsl:text > </xsl:text>
              <xsl:value-of select="adf:FormatXmlDate(DueTime,'t')"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  (Не указан)
                </xsl:when>
                <xsl:otherwise>
                  (none)
                </xsl:otherwise>
              </xsl:choose>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>

      <tr>
        <td>
          <br />
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Приоритет:
              </xsl:when>
              <xsl:otherwise>
                Priority:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:choose>
            <xsl:when test="PriorityID">
              <xsl:value-of select="adf:GetListMember(PriorityID, 'Priority', 'Name')"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  (Не указан)
                </xsl:when>
                <xsl:otherwise>
                  (none)
                </xsl:otherwise>
              </xsl:choose>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <tr>
        <td>
          <br />
          <strong>
            <xsl:choose>
              <xsl:when test="$lang = 'ru'">
                Готово, %:
              </xsl:when>
              <xsl:otherwise>
                Complete, %:
              </xsl:otherwise>
            </xsl:choose>
          </strong>
          <xsl:choose>
            <xsl:when test="PercentComplete">
              <xsl:value-of select="PercentComplete"/>
            </xsl:when>
            <xsl:otherwise>
              <xsl:choose>
                <xsl:when test="$lang = 'ru'">
                  (Не указан)
                </xsl:when>
                <xsl:otherwise>
                  (none)
                </xsl:otherwise>
              </xsl:choose>
            </xsl:otherwise>
          </xsl:choose>
        </td>
      </tr>
      <xsl:choose>
        <xsl:when test="SupervisorEmployeeID">
          <tr>
            <td>
              <br />
              <strong>
                <xsl:choose>
                  <xsl:when test="$lang = 'ru'">
                    Контролер:
                  </xsl:when>
                  <xsl:otherwise>
                    Supervisor:
                  </xsl:otherwise>
                </xsl:choose>
              </strong>
              <xsl:value-of select="adf:GetListMember(SupervisorEmployeeID, 'Employee', 'Name')"/>
            </td>
          </tr>
        </xsl:when>
      </xsl:choose>
      <xsl:choose>
        <xsl:when test="adf:GetParameter('Pjm5','AdvancedTimeExpensesForm')='True'">
          <tr>
            <td>
              <xsl:choose>
                <xsl:when test="ManHour">
                  <br />
                  <strong> 
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Трудозатраты:
                    </xsl:when>
                    <xsl:otherwise>
                      ManHour:
                    </xsl:otherwise>
                  </xsl:choose>
                </strong>
                  <br />
<xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Планируемая:
                    </xsl:when>
                    <xsl:otherwise>
                      Planned:
                    </xsl:otherwise>
                  </xsl:choose><xsl:variable name="x" select="ManHour" />
                  <xsl:choose>
                    <xsl:when test="($x div 60) >= 1">
                      <xsl:value-of select="format-number(($x - ($x mod 60)) div 60,'0')"/>
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          час.
                        </xsl:when>
                        <xsl:otherwise>
                          hour.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>
                    <xsl:when test="($x div 60) = 0">
                      <xsl:value-of select="format-number(0,'0')"/>                      
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          мин.
                        </xsl:when>
                        <xsl:otherwise>
                         min.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>  </xsl:otherwise>
                  </xsl:choose>
                  <xsl:choose>
                    <xsl:when test="($x mod 60) != 0">
                      <xsl:value-of select="format-number($x mod 60,'0')"/>  
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          мин.
                        </xsl:when>
                        <xsl:otherwise>
                          min.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>

                    <xsl:otherwise>  </xsl:otherwise>
                  </xsl:choose>
                  <br />
                  <xsl:choose>
                    <xsl:when test="$lang = 'ru'">
                      Фактическая:
                    </xsl:when>
                    <xsl:otherwise>
                      Real:
                    </xsl:otherwise>
                  </xsl:choose><xsl:variable name="y" select="ActualManHour"/>
                  <xsl:choose>
                    <xsl:when test="($y div 60) >= 1">
                      <xsl:value-of select="format-number(($y - ($y mod 60)) div 60,'0')"/>                       <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          час.
                        </xsl:when>
                        <xsl:otherwise>
                          hour.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>
                    <xsl:when test="($y div 60) = 0">
                      <xsl:value-of select="format-number(0,'0')"/>  <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          мин.
                        </xsl:when>
                        <xsl:otherwise>
                          min.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>  </xsl:otherwise>
                  </xsl:choose>
                  <xsl:choose>
                    <xsl:when test="($y mod 60) != 0">
                      <xsl:value-of select="format-number($y mod 60,'0')"/>  <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          мин.
                        </xsl:when>
                        <xsl:otherwise>
                          min.
                        </xsl:otherwise>
                      </xsl:choose>
                    </xsl:when>
                    <xsl:otherwise>  </xsl:otherwise>
                  </xsl:choose>
                  <br />
                </xsl:when>
                <xsl:otherwise>	 </xsl:otherwise>
              </xsl:choose>
            </td>
          </tr>
          <xsl:choose>
            <xsl:when test="HasFinanceAccess = 'true'">
              <tr>
                <td>
                  <xsl:choose>
                    <xsl:when test="Budget">
                      <br />
                      <strong>
                        <xsl:choose>
                          <xsl:when test="$lang = 'ru'">
                            Бюджет:
                          </xsl:when>
                          <xsl:otherwise>
                            Budget:
                          </xsl:otherwise>
                        </xsl:choose>
                      </strong>
                      <br />
                      
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          Планируемый:
                        </xsl:when>
                        <xsl:otherwise>
                          Planned:
                        </xsl:otherwise>
                      </xsl:choose><xsl:variable name="bp" select="Budget"/>
                      <xsl:value-of select="format-number($bp,'0.##')"/><xsl:text> </xsl:text> <xsl:value-of select="CurrencyCode"/> <br />
                      <xsl:choose>
                        <xsl:when test="$lang = 'ru'">
                          Фактический:
                        </xsl:when>
                        <xsl:otherwise>
                          Real:
                        </xsl:otherwise>
                      </xsl:choose><xsl:variable name="bf" select="ActualBudget"/>
                      <xsl:value-of select="format-number($bf,'0.##')"/> <xsl:text> </xsl:text> <xsl:value-of select="CurrencyCode"/> <br />
                    </xsl:when>
                    <xsl:otherwise>	 </xsl:otherwise>
                  </xsl:choose>
                </td>
              </tr>
            </xsl:when>
          </xsl:choose>
        </xsl:when>
      </xsl:choose>
    </table>
  </xsl:template>
</xsl:stylesheet>